gchecky.model.deliver_order_t

Package gchecky :: Module model :: Class deliver_order_t |
[hide private]
[frames] | no frames]

# Class deliver_order_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
      abstract_order_t --+
                         |
                        deliver_order_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``deliver-order``'`` The document's unique xml tag name.
| tracking_data = `Node:PATH(tracking-data):OPT:{ tracking_data_t }`
| send_email = `gxml.Boolean('send-email', required= False)`
| _fields = ``{``'``google_order_number``'``:` ID:PATH(@google-order-number`...`` list of meta-Fields of this class.
Inherited from `abstract_order_t`: `google_order_number`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'google_order_number': ID:PATH(@google-order-number):REQ,
       'send_email': ??,
       'tracking_data': Node:PATH(tracking-data):OPT:{ tracking_data_t }}